@@ -1,13 +1,17 @@
 from os import SEEK_SET, SEEK_END, SEEK_CUR
 from datetime import datetime, date
+from logging import getLogger
 from struct import unpack
 
-from numpy import array, dtype, empty, fromfile, iinfo, memmap, NaN, pad
+from numpy import array, dtype, empty, fromfile, iinfo, memmap, NaN, pad, where
+from numpy.lib.recfunctions import append_fields
 
 N_ZONES = 15
 MAX_SAMPLE = 128
 MAX_CAN_VIEW = 128
 
+lg = getLogger(__name__)
+
 
 class Micromed:
     """Basic class to read Micromed data. Supports .TRC and .VWR files
@@ -146,27 +150,28 @@ class Micromed:
 
     def return_videos(self, begtime, endtime):
         vid = self._videos
+        begtime *= 1000
+        endtime *= 1000
 
         # remove empty rows
-        DTYPE_MAX = iinfo(vid.dtype['delay']).max
-        vid = vid[vid['delay'] != DTYPE_MAX]
+        DTYPE_MAX = iinfo(vid.dtype['duration']).max
+        vid = vid[vid['duration'] != DTYPE_MAX]
 
         if vid.shape[0] == 0:
             raise OSError('No videos for this dataset')
 
-        if vid.shape[0] > 1:
-            raise NotImplementedError('Currently it handles only one video.')
-
-        # TODO: to test if delay is positive or negative
-        video_beg = begtime + vid['delay'].item() / 1000
-        video_end = endtime + vid['delay'].item() / 1000
+        vid = append_fields(vid, 'absolute_end', vid['delay'] + vid['duration'], usemask=False)
 
         # full name without number
-        video_name = 'VID_' + str(vid['file_ext'].item()) + '.AVI'
+        i_vid = where((endtime - vid['delay'] >= 0) & (vid['absolute_end'] - begtime >= 0))[0]
+        mpgfiles = ['VID_' + str(vid['file_ext'][i]) + '.AVI' for i in i_vid]
+        mpgfiles = [str(self.filename.parent / mpg) for mpg in mpgfiles]
 
-        mpgfiles = [
-            str(self.filename.parent / video_name),
-            ]
+        video_beg = (begtime - vid['delay'][i_vid[0]]) / 1000
+        video_end = (endtime - vid['delay'][i_vid[-1]]) / 1000
+
+        lg.debug('First Video (#{}) starts at {}'.format(mpgfiles[0], video_beg))
+        lg.debug('Last Video (#{}) ends at {}'.format(mpgfiles[-1], video_end))
 
         return mpgfiles, video_beg, video_end
 
@@ -182,7 +187,10 @@ def _read_header(f):
     orig['surname'] = f.read(22).decode('utf-8').strip()
     orig['name'] = f.read(20).decode('utf-8').strip()
     month, day, year = unpack('bbb', f.read(3))
-    orig['date_of_birth'] = date(year + 1900, month, day)
+    try:
+        orig['date_of_birth'] = date(year + 1900, month, day)
+    except ValueError:
+        orig['date_of_birth'] = None
     f.seek(19, SEEK_CUR)
 
     # recording
@@ -259,7 +267,7 @@ def _read_header(f):
 
     pos, length = zones['DVIDEO']
     f.seek(pos, 0)
-    DTYPE = dtype([('delay', 'u4'), ('duration', 'u4'), ('file_ext', 'u4'), ('empty', 'u4')])
+    DTYPE = dtype([('delay', 'i4'), ('duration', 'u4'), ('file_ext', 'u4'), ('empty', 'u4')])
     dvideo = fromfile(f, dtype=DTYPE, count=int(length / DTYPE.itemsize))
 
     # events
