@@ -2,7 +2,7 @@
 """
 from logging import getLogger
 
-from numpy import (abs, angle, asarray, ceil, diff, empty, floor, inf, 
+from numpy import (abs, angle, asarray, ceil, diff, empty, floor, inf,
                    logical_and, logical_or, mean, ravel, stack, zeros)
 from functools import partial
 from csv import writer
@@ -54,9 +54,10 @@ from PyQt5.QtWidgets import (QAbstractItemView,
                              )
 
 from .. import ChanFreq, __version__
-from ..trans import (math, filter_, frequency, get_descriptives, 
-                     fetch, get_times, event_params, export_event_params,
-                     export_freq, export_freq_band)
+from ..trans import (math, filter_, frequency, get_descriptives,
+                     fetch, get_times)
+from ..trans.analyze import (event_params, export_event_params,
+                             export_freq, export_freq_band)
 from .modal_widgets import ChannelDialog
 from .utils import (FormStr, FormInt, FormFloat, FormBool, FormMenu, FormRadio,
                     FormSpin, freq_from_str, short_strings, STAGE_NAME, ICON)
@@ -192,13 +193,13 @@ class AnalysisDialog(ChannelDialog):
 
         self.min_dur = FormFloat(0.0)
         self.reject_epoch = FormBool('Exclude Poor signal epochs')
-        self.reject_event = FormMenu(['none', 'channel-specific', 
+        self.reject_event = FormMenu(['none', 'channel-specific',
                                       'from any channel'])
 
         flayout = QFormLayout()
         box_r.setLayout(flayout)
         flayout.addRow(self.reject_epoch)
-        flayout.addRow('Exclude Artefact events', 
+        flayout.addRow('Exclude Artefact events',
                        self.reject_event)
         flayout.addRow('Minimum duration (sec)',
                            self.min_dur)
@@ -308,12 +309,14 @@ class AnalysisDialog(ChannelDialog):
                 'blackmanharris', 'nuttall', 'barthann'])
         freq['detrend'] = FormMenu(['none', 'constant', 'linear'])
         freq['welch_on'] = FormBool("Time-averaged")
+        freq['log_trans']= FormBool('Log-transform')
 
-        flayout = QFormLayout(freq['box_param'])
-        flayout.addRow('Scaling', freq['scaling'])
-        flayout.addRow('Taper', freq['taper'])
-        flayout.addRow('Detrend', freq['detrend'])
-        flayout.addRow(freq['welch_on'])
+        form = QFormLayout(freq['box_param'])
+        form.addRow('Scaling', freq['scaling'])
+        form.addRow('Taper', freq['taper'])
+        form.addRow('Detrend', freq['detrend'])
+        form.addRow(freq['welch_on'])
+        form.addRow(freq['log_trans'])
 
         freq['box_welch'] = QGroupBox("Time averaging")
 
@@ -325,6 +328,7 @@ class AnalysisDialog(ChannelDialog):
         freq['overlap_val'].setSingleStep(0.1)
         freq['overlap_val'].setValue(0.5)
         freq['step_val'] = FormFloat(0.5)
+        freq['centend'] = FormMenu(['mean', 'median'])
 
         grid = QGridLayout(freq['box_welch'])
         grid.addWidget(QLabel('Duration (sec)'), 0, 0)
@@ -333,6 +337,8 @@ class AnalysisDialog(ChannelDialog):
         grid.addWidget(freq['step'], 2, 0)
         grid.addWidget(freq['overlap_val'], 1, 1)
         grid.addWidget(freq['step_val'], 2, 1)
+        grid.addWidget(QLabel('Central tendency'), 3, 0)
+        grid.addWidget(freq['centend'], 3, 1)
 
         freq['box_mtap'] = QGroupBox('Multitaper method (DPSS) smoothing')
 
@@ -609,8 +615,8 @@ class AnalysisDialog(ChannelDialog):
         el['maxamp'] = FormBool('Max. amplitude (uV)'), FormBool('')
         el['ptp'] = FormBool('Peak-to-peak amplitude (uV)'), FormBool('')
         el['rms'] = FormBool('RMS (uV)'), FormBool('')
-        el['power'] = FormBool('Power (uV**2)'), FormBool('')
-        el['energy'] = FormBool('Energy (uV**2 / s)'), FormBool('')
+        el['power'] = FormBool('Power (uV^2)'), FormBool('')
+        el['energy'] = FormBool('Energy (uV^2s)'), FormBool('')
         el['peakpf'] = FormBool('Peak power frequency (Hz)'), FormBool('')
         el['peakef'] = FormBool('Peak energy frequency (Hz)'), FormBool('')
 
@@ -621,7 +627,7 @@ class AnalysisDialog(ChannelDialog):
         ev['sw']['invert'] = FormBool('Inverted (down-then-up)')
         ev['sw']['prep'] = FormBool('Pre-process')
         ev['sw']['avg_slope'] = FormBool('Average slopes (uV/s)')
-        ev['sw']['max_slope'] = FormBool('Max. slopes (uV/s**2)')
+        ev['sw']['max_slope'] = FormBool('Max. slopes (uV/s^2)')
 
         box_global = QGroupBox('Global')
 
@@ -1319,7 +1325,7 @@ class AnalysisDialog(ChannelDialog):
                 for one_xf, suffix, prefix, ylabel, scale in freq_out:
 
                     if freq_band:
-                        filename = (splitext(self.filename)[0] + '_' + suffix + 
+                        filename = (splitext(self.filename)[0] + '_' + suffix +
                                     '_band.csv')
                         export_freq_band(one_xf, bands, filename)
 
@@ -1339,7 +1345,7 @@ class AnalysisDialog(ChannelDialog):
                                 y = desc['mean']
 
                             if freq_full:
-                                filename = (splitext(self.filename)[0] + '_' + 
+                                filename = (splitext(self.filename)[0] + '_' +
                                             suffix + '_full.csv')
                                 export_freq(one_xf, filename, desc=desc)
 
@@ -1374,7 +1380,7 @@ class AnalysisDialog(ChannelDialog):
             if (evt_dat or count or density):
                 fn = splitext(self.filename)[0] + '_params.csv'
                 export_event_params(fn, evt_dat, count=count, density=density)
-            
+
             self.parent.overview.mark_poi() # remove poi
             self.accept()
 
@@ -1440,7 +1446,7 @@ class AnalysisDialog(ChannelDialog):
         cat = {k: v.get_value() for k, v in self.cat.items()}
         cat = (int(cat['cycle']), int(cat['stage']),
                int(cat['discontinuous']), int(cat['evt_type']))
-        
+
         # Artefact event rejection
         reject_event = self.reject_event.get_value()
         if reject_event == 'channel-specific':
@@ -1451,7 +1457,7 @@ class AnalysisDialog(ChannelDialog):
             reject_artf = True
         else:
             reject_artf = False
-            
+
         # Other options
         min_dur = self.min_dur.get_value()
         reject_epoch = self.reject_epoch.get_value()
@@ -1564,6 +1570,7 @@ class AnalysisDialog(ChannelDialog):
         freq = self.frequency
         prep = freq['prep'].get_value()
         scaling = freq['scaling'].get_value()
+        log_trans = freq['log_trans'].get_value()
         #sides = freq['sides'].get_value()
         taper = freq['taper'].get_value()
         halfbandwidth = freq['hbw'].get_value()
@@ -1571,6 +1578,7 @@ class AnalysisDialog(ChannelDialog):
         duration = freq['duration'].get_value()
         overlap = freq['overlap_val'].value()
         step = freq['step_val'].get_value()
+        centend = freq['centend'].get_value()
         detrend = freq['detrend'].get_value()
         norm = freq['norm'].get_value()
         norm_concat = freq['norm_concat'].get_value()
@@ -1663,7 +1671,8 @@ class AnalysisDialog(ChannelDialog):
                                 sides=sides, taper=taper,
                                 halfbandwidth=halfbandwidth, NW=NW,
                                 duration=duration, overlap=overlap, step=step,
-                                detrend=detrend, n_fft=n_fft)
+                                detrend=detrend, n_fft=n_fft, 
+                                log_trans=log_trans, centend=centend)
                 except ValueError:
                     msg = ('Value error encountered in frequency '
                            'transformation for normalization reference data.'
@@ -1695,7 +1704,8 @@ class AnalysisDialog(ChannelDialog):
                          str(NW), 'dur:', str(duration), 'overlap:',
                          str(overlap), 'step:', str(step), 'detrend:',
                          str(detrend), 'n_fft:', str(n_fft), 'norm',
-                         str(norm)]))
+                         str(norm), 'log:', str(log_trans), 'central tendency',
+                         str(centend)]))
 
         # Main frequency analysis
         xfreq = []
@@ -1716,7 +1726,8 @@ class AnalysisDialog(ChannelDialog):
                                 sides=sides, taper=taper,
                                 halfbandwidth=halfbandwidth, NW=NW,
                                 duration=duration, overlap=overlap, step=step,
-                                detrend=detrend, n_fft=n_fft)
+                                detrend=detrend, n_fft=n_fft, 
+                                log_trans=log_trans, centend=centend)
             except SyntaxError:
                 msg = 'Value error encountered in frequency transformation.'
                 error_dialog = QErrorMessage(self)
@@ -2198,13 +2209,13 @@ class AnalysisDialog(ChannelDialog):
         if not f2:
             f2 = None
         band = (f1, f2)
-        
+
         if not (slopes['avg_slope'] or slopes['max_slope']):
             slopes = None
-        
-        evt_dat = event_params(self.data, params, band=band, slopes=slopes, 
+
+        evt_dat = event_params(self.data, params, band=band, slopes=slopes,
                                prep=prep, parent=self)
-        
+
         count = None
         density = None
         if glob['count']:
@@ -2216,9 +2227,9 @@ class AnalysisDialog(ChannelDialog):
                             cycle=self.cycle, exclude=True)
             total_dur = sum([x[1] - x[0] for y in poi for x in y['times']])
             density = len(self.data) / (total_dur / epoch_dur)
-        
-        return evt_dat, count, density                
- 
+
+        return evt_dat, count, density
+
     def make_title(self, chan, cycle, stage, evt_type):
         """Make a title for plots, etc."""
         cyc_str = None
