@@ -68,7 +68,9 @@ STAGE_SHORTCUT = ['1', '2', '3', '5', '9', '8', '0', '', '', '7']
 QUALIFIERS = ['Good', 'Poor']
 QUALITY_SHORTCUT = ['o', 'p']
 SPINDLE_METHODS = ['Moelle2011',
+                   'Lacourse2018',
                    'Ray2015',
+                   'Martin2013',
                    'Wamsley2012',  
                    'Nir2011', 
                    'Ferrarelli2007',
@@ -296,6 +298,10 @@ class Notes(QTabWidget):
         act = QAction('New...', self)
         act.triggered.connect(self.new_rater)
         actions['new_rater'] = act
+        
+        act = QAction('Rename...', self)
+        act.triggered.connect(self.rename_rater)
+        actions['rename_rater'] = act
 
         act = QAction('Delete...', self)
         act.triggered.connect(self.delete_rater)
@@ -313,15 +319,15 @@ class Notes(QTabWidget):
         act.triggered.connect(self.delete_eventtype)
         actions['del_eventtype'] = act
         
-        act = QAction('Rename event type', self)
+        act = QAction('Rename Event Type', self)
         act.triggered.connect(self.rename_eventtype)
         actions['rename_eventtype'] = act
 
-        act = QAction('New name', self)
+        act = QAction('New Name', self)
         act.triggered.connect(self.markers_to_events)
         actions['m2e_newname'] = act
         
-        act = QAction('Keep marker names', self)
+        act = QAction('Keep Marker Names', self)
         act.triggered.connect(partial(self.markers_to_events, True))
         actions['m2e_keepname'] = act
         
@@ -360,21 +366,21 @@ class Notes(QTabWidget):
 
         actions['quality'] = act
 
-        act = QAction('Set cycle start', self)
+        act = QAction('Set Cycle Start', self)
         act.setShortcut('Ctrl+[')
         act.triggered.connect(self.get_cycle_mrkr)
         actions['cyc_start'] = act
 
-        act = QAction('Set cycle end', self)
+        act = QAction('Set Cycle End', self)
         act.setShortcut('Ctrl+]')
         act.triggered.connect(partial(self.get_cycle_mrkr, end=True))
         actions['cyc_end'] = act
 
-        act = QAction('Remove cycle marker', self)
+        act = QAction('Remove Cycle Marker', self)
         act.triggered.connect(self.remove_cycle_mrkr)
         actions['remove_cyc'] = act
 
-        act = QAction('Clear cycle markers', self)
+        act = QAction('Clear Cycle Markers', self)
         act.triggered.connect(self.clear_cycle_mrkrs)
         actions['clear_cyc'] = act
 
@@ -401,6 +407,10 @@ class Notes(QTabWidget):
         act = QAction('PRANA', self)
         act.triggered.connect(partial(self.import_staging, 'prana'))
         actions['import_prana'] = act
+        
+        act = QAction('DeltaMed', self)
+        act.triggered.connect(partial(self.import_staging, 'deltamed'))
+        actions['import_deltamed'] = act
 
         act = QAction('FASST', self)
         act.triggered.connect(self.import_fasst)
@@ -436,9 +446,18 @@ class Notes(QTabWidget):
                                       as_qual=True))
         actions['import_prana_qual'] = act
         
-        act = QAction('Import events', self)
-        act.triggered.connect(self.import_events)
-        actions['imp_evt_csv'] = act
+        act = QAction('DeltaMed', self)
+        act.triggered.connect(partial(self.import_staging, 'deltamed', 
+                                      as_qual=True))
+        actions['import_deltamed_qual'] = act
+        
+        act = QAction('Wonambi', self)
+        act.triggered.connect(partial(self.import_events, 'wonambi'))
+        actions['import_events_wonambi'] = act
+        
+        act = QAction('RemLogic', self)
+        act.triggered.connect(partial(self.import_events, 'remlogic'))
+        actions['import_events_remlogic'] = act
 
         act = QAction('CSV', self)
         act.triggered.connect(partial(self.export, xformat='csv'))
@@ -452,7 +471,7 @@ class Notes(QTabWidget):
         act.triggered.connect(partial(self.export, xformat='remlogic_fr'))
         actions['export_to_remlogic_fr'] = act
 
-        act = QAction('Export events...', self)
+        act = QAction('Export Events...', self)
         act.triggered.connect(self.parent.show_export_events_dialog)
         actions['export_events'] = act
 
@@ -462,19 +481,19 @@ class Notes(QTabWidget):
         act.setEnabled(False)
         actions['spindle'] = act
 
-        act = QAction('Slow wave...', self)
+        act = QAction('Slow Wave...', self)
         act.triggered.connect(self.parent.show_slow_wave_dialog)
         act.setShortcut('Ctrl+Shift+w')
         act.setEnabled(False)
         actions['slow_wave'] = act
 
-        act = QAction('Analysis console', self)
+        act = QAction('Analysis Console', self)
         act.triggered.connect(self.parent.show_analysis_dialog)
         act.setShortcut('Ctrl+Shift+a')
         act.setEnabled(False)
         actions['analyze'] = act
 
-        act = QAction('Sleep statistics', self)
+        act = QAction('Sleep Statistics', self)
         act.triggered.connect(self.export_sleeps_stats)
         actions['export_sleepstats'] = act
 
@@ -1224,7 +1243,7 @@ class Notes(QTabWidget):
         else:
             rater = test_rater
 
-        if source == 'compumedics':
+        if source in ['deltamed', 'compumedics']:
             time_str, ok = QInputDialog.getText(self, 'Staging start time',
                                                 'Enter date and time when '
                                                 'staging \nbegins, using '
@@ -1312,6 +1331,24 @@ class Notes(QTabWidget):
             self.display_notes()
             self.parent.create_menubar()  # refresh list ot raters
 
+    def rename_rater(self, test_name=None, test_new_name=None):
+        """action: create dialog to rename event type."""
+        if test_name and test_new_name:
+            name = test_name, True
+            new_name = test_new_name, True
+        else:
+            name = QInputDialog.getText(self, 'Rename Rater',
+                                        'Enter name of rater to rename.')
+        
+        if name[1]:
+            new_name = QInputDialog.getText(self, 'Rename Rater',
+                                            'Enter new name for rater.')
+            
+            if new_name[1]:
+                self.annot.rename_rater(name[0], new_name[0])
+                self.display_notes()
+                self.parent.create_menubar()  # refresh list ot raters
+
     def new_eventtype(self, test_type_str=None):
         """Action: create dialog to add new event type."""
         if self.annot is None:  # remove if buttons are disabled
@@ -1402,30 +1439,13 @@ class Notes(QTabWidget):
             return
         
         if not keep_name:
-            name, ok = self.new_eventtype()
-            
+            name, ok = self.new_eventtype()            
             if not ok:
-                return
-
-        progress = QProgressDialog('Saving events', 'Abort',
-                                       0, len(markers), self)
-        progress.setWindowModality(Qt.ApplicationModal)
-        
-        for i, mrk in enumerate(markers):
-            progress.setValue(i)
-            
-            if keep_name:
-                name = mrk['name']
+                return            
+        else:
+            name = None
                 
-            self.annot.add_event(name, (mrk['start'], mrk['end']), chan='')
-            
-            if progress.wasCanceled():
-                msg = ('Conversion interrupted. Not all events were saved '
-                       'to the Annotations File.')
-                self.parent.statusBar().showMessage(msg)
-                return
-            
-        progress.setValue(i + 1)
+        self.annot.add_events(markers, name=name, chan='')
         
         if keep_name:
             self.display_eventtype()
@@ -1467,21 +1487,72 @@ class Notes(QTabWidget):
         if method in SPINDLE_METHODS:
             detector = DetectSpindle(method=method, frequency=freq,
                                      duration=duration, merge=params['merge'])
-
-            if method in ['Wamsley2012', 'UCSD']:
-                detector.det_wavelet['dur'] = params['win_sz']
-            elif method == 'Ray2015':
-                detector.zwin['dur'] = params['win_sz']
-            else:
-                detector.moving_rms['dur'] = params['win_sz']
-
-            detector.det_wavelet['sd'] = params['sigma']
-            detector.smooth['dur'] = params['smooth']
-            detector.det_thresh_lo = params['det_thresh_lo']
-            detector.det_thresh_hi = params['det_thresh_hi']
-            detector.sel_thresh = params['sel_thresh']
+            detector.rolloff = params['rolloff']
             detector.min_interval = params['interval']
 
+            if 'Ferrarelli2007' == method:
+                detector.det_thresh = params['0']
+                detector.sel_thresh = params['1']
+                
+            if 'Nir2011' == method:
+                detector.smooth['dur'] = params['0']
+                detector.det_thresh = params['1']
+                detector.sel_thresh = params['2']
+                
+            if 'Moelle2011' == method:
+                detector.moving_rms['dur'] = params['0']
+                detector.smooth['dur'] = params['1']
+                detector.det_thresh = params['2']            
+            
+            if 'Wamsley2012' == method:
+                detector.det_wavelet['dur'] = params['0']
+                detector.det_wavelet['sd'] = params['1']
+                detector.smooth['dur'] = params['2']  
+                detector.det_thresh = params['3']  
+            
+            if 'Martin2013' == method:
+                detector.moving_rms['dur'] = params['0']
+                detector.moving_rms['step'] = params['1']
+                detector.det_thresh = params['2']
+            
+            if 'Ray2015' == method:
+                detector.smooth['dur'] = params['0']
+                detector.zscore['step'] = params['1']
+                detector.det_thresh = params['2']  
+                detector.sel_thresh = params['3']             
+            
+            if 'Lacourse2018' == method:
+                detector.windowing['dur'] = params['0']
+                detector.windowing['step'] = params['1']
+                detector.abs_pow_thresh = params['2']
+                detector.rel_pow_thresh = params['3']
+                detector.covar_thresh = params['4']
+                detector.corr_thresh = params['5']
+                
+            if 'FASST' == method:
+                detector.det_thresh = params['0']
+                detector.smooth['dur'] = params['1']
+                
+            if 'FASST2' == method:
+                detector.det_thresh = params['0']
+                detector.moving_rms['dur'] = params['1']
+                detector.smooth['dur'] = params['2']
+            
+            if 'UCSD' == method:
+                detector.det_wavelet['dur'] = params['0']
+                detector.det_wavelet['width'] = params['1']
+                detector.det_wavelet['win'] = params['2']
+                detector.det_thresh = params['3']  
+                detector.sel_thresh = params['4'] 
+                
+            if 'Concordia' == method:
+                detector.moving_rms['dur'] = params['0']
+                detector.smooth['dur'] = params['1']
+                detector.det_thresh = params['2']            
+                detector.det_thresh_hi = params['3']            
+                detector.tolerance = params['4']            
+                detector.sel_thresh = params['5']            
+                
         elif method in SLOW_WAVE_METHODS:
             detector = DetectSlowWave(method=method, duration=duration)
 
@@ -1499,22 +1570,7 @@ class Notes(QTabWidget):
         events = detector(data, parent=self)
 
         if events:
-            progress = QProgressDialog('Saving events', 'Abort',
-                                       0, len(events), self)
-            progress.setWindowModality(Qt.ApplicationModal)
-    
-            for i, one_ev in enumerate(events):
-                progress.setValue(i)
-                self.annot.add_event(label,(one_ev['start'],
-                                            one_ev['end']),
-                                            chan=one_ev['chan'])
-                if progress.wasCanceled():
-                    msg = ('Saving interrupted. Not all events were saved '
-                           'to the Annotations File.')
-                    self.parent.statusBar().showMessage(msg)
-                    return
-    
-            progress.setValue(i + 1)
+            self.annot.add_events(events, name=label)
 
         self.update_annotations()
 
@@ -1539,21 +1595,31 @@ class Notes(QTabWidget):
 
         self.annot.export(filename, xformat=xformat)
 
-    def import_events(self):
-        """action: import events from Wonambi CSV event export."""
+    def import_events(self, source='wonambi'):
+        """action: import events from text file (Wonambi or RemLogic)."""
         if self.annot is None:  # remove if buttons are disabled
             self.parent.statusBar().showMessage('No score file loaded')
             return
 
+        if 'wonambi' == source:
+            format_str = 'CSV File (*.csv)'
+            rec_start = None
+        
+        elif 'remlogic' == source:
+            format_str = 'Text file (*.txt)'
+            rec_start = self.parent.info.dataset.header['start_time']
+            
+        
         fn, _ = QFileDialog.getOpenFileName(self, 'Import events',
-                                            None, 'CSV File (*.csv)')
+                                            None, format_str)
         
         if fn == '':
             return
         
         fn = Path(fn).resolve()
 
-        self.annot.import_events(fn, parent=self.parent)
+        self.annot.import_events(fn, source=source, rec_start=rec_start,
+                                 parent=self.parent)
         self.display_notes()        
     
     def export_sleeps_stats(self):
@@ -1758,9 +1824,7 @@ class MergeDialog(QDialog):
             for etype in evt_types:
                 self.parent.notes.annot.remove_event_type(etype)
 
-            for ev in events:
-                self.parent.notes.add_event(name, (ev['start'], ev['end']),
-                                            ev['chan'])
+            self.parent.notes.add_events(events, name=name, chan=None)
 
             self.parent.notes.display_eventtype()
             n_eventtype = self.parent.notes.idx_eventtype.count()
@@ -1894,6 +1958,7 @@ class ExportEventsDialog(QDialog):
                     self.parent.statusBar.showMessage('No events found.')
                     return
                 
+                events = sorted(events, key=lambda x: x['start'])
                 dataset = self.parent.info.dataset
                 data = ChanTime()
                 data.start_time = dataset.header['start_time']
